@@ -70,7 +70,14 @@ bool Identity::isNull() const
         }
         // The uoid is 0 by default, so ignore this
         if (!(key == QLatin1String(s_uoid) && i.value().toUInt() == 0)) {
-            if (!i.value().isNull() || (i.value().type() == QVariant::String && !i.value().toString().isEmpty())) {
+            if (!i.value().isNull()
+                || (
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+                    i.value().type() == QVariant::String
+#else
+                    i.value().metaType().id() == QMetaType::QString
+#endif
+                    && !i.value().toString().isEmpty())) {
                 empty = false;
             }
         }
@@ -98,8 +105,7 @@ void Identity::readConfig(const KConfigGroup &config)
     // needs to update to v5.21.41
     // Check if we update to to encryption override mode
     // before we had only auto_encrypt and auto_sign and no global setting
-    if (!mPropertiesMap.contains(QLatin1String(s_encryptionOverride))
-        && !mPropertiesMap.contains(QLatin1String(s_warnnotencrypt))
+    if (!mPropertiesMap.contains(QLatin1String(s_encryptionOverride)) && !mPropertiesMap.contains(QLatin1String(s_warnnotencrypt))
         && !mPropertiesMap.contains(QLatin1String(s_warnnotsign))) {
         setEncryptionOverride(true);
     }
@@ -117,7 +123,7 @@ void Identity::writeConfig(KConfigGroup &config) const
     }
     if (!mPropertiesMap.contains(QLatin1String(s_encryptionOverride))) {
         config.writeEntry(QLatin1String(s_encryptionOverride), false);
-        qCDebug(KIDENTITYMANAGEMENT_LOG) << "Add" <<  s_encryptionOverride << ":" << false;
+        qCDebug(KIDENTITYMANAGEMENT_LOG) << "Add" << s_encryptionOverride << ":" << false;
     }
     mSignature.writeConfig(config);
 }
@@ -172,14 +178,12 @@ QDataStream &KIdentityManagement::operator<<(QDataStream &stream, const KIdentit
                   << i.mPropertiesMap[QLatin1String(s_emailAliases)] << i.mPropertiesMap[QLatin1String(s_replyto)] << i.mPropertiesMap[QLatin1String(s_bcc)]
                   << i.mPropertiesMap[QLatin1String(s_vcard)] << i.mPropertiesMap[QLatin1String(s_transport)] << i.mPropertiesMap[QLatin1String(s_fcc)]
                   << i.mPropertiesMap[QLatin1String(s_drafts)] << i.mPropertiesMap[QLatin1String(s_templates)] << i.mSignature
-                  << i.mPropertiesMap[QLatin1String(s_dict)]
-                  << i.mPropertiesMap[QLatin1String(s_xface)] << i.mPropertiesMap[QLatin1String(s_xfaceenabled)]
-                  << i.mPropertiesMap[QLatin1String(s_face)] << i.mPropertiesMap[QLatin1String(s_faceenabled)]
-                  << i.mPropertiesMap[QLatin1String(s_prefcrypt)] << i.mPropertiesMap[QLatin1String(s_cc)] << i.mPropertiesMap[QLatin1String(s_attachVcard)]
+                  << i.mPropertiesMap[QLatin1String(s_dict)] << i.mPropertiesMap[QLatin1String(s_xface)] << i.mPropertiesMap[QLatin1String(s_xfaceenabled)]
+                  << i.mPropertiesMap[QLatin1String(s_face)] << i.mPropertiesMap[QLatin1String(s_faceenabled)] << i.mPropertiesMap[QLatin1String(s_prefcrypt)]
+                  << i.mPropertiesMap[QLatin1String(s_cc)] << i.mPropertiesMap[QLatin1String(s_attachVcard)]
                   << i.mPropertiesMap[QLatin1String(s_autocorrectionLanguage)] << i.mPropertiesMap[QLatin1String(s_disabledFcc)]
-                  << i.mPropertiesMap[QLatin1String(s_defaultDomainName)]
-                  << i.mPropertiesMap[QLatin1String(s_autocryptEnabled)] << i.mPropertiesMap[QLatin1String(s_autocryptPrefer)]
-                  << i.mPropertiesMap[QLatin1String(s_encryptionOverride)]
+                  << i.mPropertiesMap[QLatin1String(s_defaultDomainName)] << i.mPropertiesMap[QLatin1String(s_autocryptEnabled)]
+                  << i.mPropertiesMap[QLatin1String(s_autocryptPrefer)] << i.mPropertiesMap[QLatin1String(s_encryptionOverride)]
                   << i.mPropertiesMap[QLatin1String(s_pgpautosign)] << i.mPropertiesMap[QLatin1String(s_pgpautoencrypt)]
                   << i.mPropertiesMap[QLatin1String(s_warnnotencrypt)] << i.mPropertiesMap[QLatin1String(s_warnnotsign)];
 }
@@ -187,20 +191,17 @@ QDataStream &KIdentityManagement::operator<<(QDataStream &stream, const KIdentit
 QDataStream &KIdentityManagement::operator>>(QDataStream &stream, KIdentityManagement::Identity &i)
 {
     quint32 uoid;
-    stream >> uoid >> i.mPropertiesMap[QLatin1String(s_identity)] >> i.mPropertiesMap[QLatin1String(s_name)]
-        >> i.mPropertiesMap[QLatin1String(s_organization)] >> i.mPropertiesMap[QLatin1String(s_pgps)] >> i.mPropertiesMap[QLatin1String(s_pgpe)]
-        >> i.mPropertiesMap[QLatin1String(s_smimes)] >> i.mPropertiesMap[QLatin1String(s_smimee)] >> i.mPropertiesMap[QLatin1String(s_primaryEmail)]
-        >> i.mPropertiesMap[QLatin1String(s_emailAliases)] >> i.mPropertiesMap[QLatin1String(s_replyto)] >> i.mPropertiesMap[QLatin1String(s_bcc)]
-        >> i.mPropertiesMap[QLatin1String(s_vcard)] >> i.mPropertiesMap[QLatin1String(s_transport)] >> i.mPropertiesMap[QLatin1String(s_fcc)]
-        >> i.mPropertiesMap[QLatin1String(s_drafts)] >> i.mPropertiesMap[QLatin1String(s_templates)] >> i.mSignature
-        >> i.mPropertiesMap[QLatin1String(s_dict)]
-        >> i.mPropertiesMap[QLatin1String(s_xface)] >> i.mPropertiesMap[QLatin1String(s_xfaceenabled)]
-        >> i.mPropertiesMap[QLatin1String(s_face)] >> i.mPropertiesMap[QLatin1String(s_faceenabled)]
+    stream >> uoid >> i.mPropertiesMap[QLatin1String(s_identity)] >> i.mPropertiesMap[QLatin1String(s_name)] >> i.mPropertiesMap[QLatin1String(s_organization)]
+        >> i.mPropertiesMap[QLatin1String(s_pgps)] >> i.mPropertiesMap[QLatin1String(s_pgpe)] >> i.mPropertiesMap[QLatin1String(s_smimes)]
+        >> i.mPropertiesMap[QLatin1String(s_smimee)] >> i.mPropertiesMap[QLatin1String(s_primaryEmail)] >> i.mPropertiesMap[QLatin1String(s_emailAliases)]
+        >> i.mPropertiesMap[QLatin1String(s_replyto)] >> i.mPropertiesMap[QLatin1String(s_bcc)] >> i.mPropertiesMap[QLatin1String(s_vcard)]
+        >> i.mPropertiesMap[QLatin1String(s_transport)] >> i.mPropertiesMap[QLatin1String(s_fcc)] >> i.mPropertiesMap[QLatin1String(s_drafts)]
+        >> i.mPropertiesMap[QLatin1String(s_templates)] >> i.mSignature >> i.mPropertiesMap[QLatin1String(s_dict)] >> i.mPropertiesMap[QLatin1String(s_xface)]
+        >> i.mPropertiesMap[QLatin1String(s_xfaceenabled)] >> i.mPropertiesMap[QLatin1String(s_face)] >> i.mPropertiesMap[QLatin1String(s_faceenabled)]
         >> i.mPropertiesMap[QLatin1String(s_prefcrypt)] >> i.mPropertiesMap[QLatin1String(s_cc)] >> i.mPropertiesMap[QLatin1String(s_attachVcard)]
         >> i.mPropertiesMap[QLatin1String(s_autocorrectionLanguage)] >> i.mPropertiesMap[QLatin1String(s_disabledFcc)]
-        >> i.mPropertiesMap[QLatin1String(s_defaultDomainName)]
-        >> i.mPropertiesMap[QLatin1String(s_autocryptEnabled)] >> i.mPropertiesMap[QLatin1String(s_autocryptPrefer)]
-        >> i.mPropertiesMap[QLatin1String(s_encryptionOverride)]
+        >> i.mPropertiesMap[QLatin1String(s_defaultDomainName)] >> i.mPropertiesMap[QLatin1String(s_autocryptEnabled)]
+        >> i.mPropertiesMap[QLatin1String(s_autocryptPrefer)] >> i.mPropertiesMap[QLatin1String(s_encryptionOverride)]
         >> i.mPropertiesMap[QLatin1String(s_pgpautosign)] >> i.mPropertiesMap[QLatin1String(s_pgpautoencrypt)]
         >> i.mPropertiesMap[QLatin1String(s_warnnotencrypt)] >> i.mPropertiesMap[QLatin1String(s_warnnotsign)];
 
@@ -511,7 +512,13 @@ void Identity::setProperty(const QString &key, const QVariant &value)
     if (key == QLatin1String(s_signature)) {
         mSignature = value.value<Signature>();
     } else {
-        if (value.isNull() || (value.type() == QVariant::String && value.toString().isEmpty())) {
+        if (value.isNull() ||
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            (value.type() == QVariant::String
+#else
+            (value.metaType().id() == QMetaType::QString
+#endif
+             && value.toString().isEmpty())) {
             mPropertiesMap.remove(key);
         } else {
             mPropertiesMap.insert(key, value);
